@@ -1,4 +1,6 @@
-pub mod conda_build;
+pub mod conda_build_v0;
+pub mod conda_build_v1;
 pub mod conda_metadata;
+pub mod conda_outputs;
 pub mod initialize;
 pub mod negotiate_capabilities;
