@@ -15,16 +15,18 @@ pub use builder::CommandDispatcherBuilder;
 pub use error::{CommandDispatcherError, CommandDispatcherErrorResultExt};
 pub(crate) use git::GitCheckoutTask;
 pub use instantiate_backend::{InstantiateBackendError, InstantiateBackendSpec};
+use pixi_build_discovery::{DiscoveredBackend, EnabledProtocols};
 use pixi_build_frontend::BackendOverride;
 use pixi_git::resolver::GitResolver;
 use pixi_glob::GlobHashCache;
 use pixi_record::{PinnedPathSpec, PinnedSourceSpec, PixiRecord};
-use pixi_spec::SourceSpec;
+use pixi_spec::{SourceLocationSpec, SourceSpec};
 use rattler::package_cache::PackageCache;
-use rattler_conda_types::{GenericVirtualPackage, Platform};
+use rattler_conda_types::{ChannelConfig, GenericVirtualPackage, Platform};
 use rattler_repodata_gateway::Gateway;
 use reqwest_middleware::ClientWithMiddleware;
 use tokio::sync::{mpsc, oneshot};
+use tokio_util::sync::CancellationToken;
 use typed_path::Utf8TypedPath;
 
 use crate::{
@@ -35,6 +37,7 @@ use crate::{
     backend_source_build::{BackendBuiltSource, BackendSourceBuildError, BackendSourceBuildSpec},
     build::{BuildCache, source_metadata_cache::SourceMetadataCache},
     cache_dirs::CacheDirs,
+    discover_backend_cache::DiscoveryCache,
     install_pixi::{
         InstallPixiEnvironmentError, InstallPixiEnvironmentResult, InstallPixiEnvironmentSpec,
     },
@@ -123,6 +126,9 @@ pub(crate) struct CommandDispatcherData {
     /// A cache for glob hashes.
     pub glob_hash_cache: GlobHashCache,
 
+    /// Cache for discovered build backends keyed by source checkout path.
+    pub discovery_cache: DiscoveryCache,
+
     /// The resolved limits for the command dispatcher.
     pub limits: ResolvedLimits,
 
@@ -350,6 +356,11 @@ impl CommandDispatcher {
         &self.data.glob_hash_cache
     }
 
+    /// Returns the discovery cache for build backends.
+    pub fn discovery_cache(&self) -> &DiscoveryCache {
+        &self.data.discovery_cache
+    }
+
     /// Returns the download client used by the command dispatcher.
     pub fn download_client(&self) -> &ClientWithMiddleware {
         &self.data.download_client
@@ -391,15 +402,20 @@ impl CommandDispatcher {
             return Err(CommandDispatcherError::Cancelled);
         };
 
+        let cancellation_token = CancellationToken::new();
         let (tx, rx) = oneshot::channel();
         sender
             .send(ForegroundMessage::from(Task {
                 spec,
                 parent: self.context,
                 tx,
+                cancellation_token: cancellation_token.clone(),
             }))
             .map_err(|_| CommandDispatcherError::Cancelled)?;
 
+        // Make sure to trigger the cancellation token when this async task is dropped.
+        let _cancel_guard = cancellation_token.drop_guard();
+
         match rx.await {
             Ok(Ok(result)) => Ok(result),
             Ok(Err(err)) => Err(CommandDispatcherError::Failed(err)),
@@ -545,11 +561,11 @@ impl CommandDispatcher {
         &self,
         source_spec: SourceSpec,
     ) -> Result<SourceCheckout, CommandDispatcherError<SourceCheckoutError>> {
-        match source_spec {
-            SourceSpec::Url(url) => {
+        match source_spec.location {
+            SourceLocationSpec::Url(url) => {
                 unimplemented!("fetching URL sources ({}) is not yet implemented", url.url)
             }
-            SourceSpec::Path(path) => {
+            SourceLocationSpec::Path(path) => {
                 let source_path = self
                     .data
                     .resolve_typed_path(path.path.to_path())
@@ -560,7 +576,7 @@ impl CommandDispatcher {
                     pinned: PinnedSourceSpec::Path(PinnedPathSpec { path: path.path }),
                 })
             }
-            SourceSpec::Git(git_spec) => self.pin_and_checkout_git(git_spec).await,
+            SourceLocationSpec::Git(git_spec) => self.pin_and_checkout_git(git_spec).await,
         }
     }
 
@@ -598,6 +614,20 @@ impl CommandDispatcher {
             }
         }
     }
+
+    /// Discovers the build backend at a specific path on disk and caches it by
+    /// path.
+    pub async fn discover_backend(
+        &self,
+        source_path: &std::path::Path,
+        channel_config: ChannelConfig,
+        enabled_protocols: EnabledProtocols,
+    ) -> Result<Arc<DiscoveredBackend>, CommandDispatcherError<pixi_build_discovery::DiscoveryError>>
+    {
+        self.discovery_cache()
+            .get_or_discover(source_path, &channel_config, &enabled_protocols)
+            .await
+    }
 }
 
 impl CommandDispatcherData {
@@ -667,4 +697,5 @@ pub(crate) struct Task<S: TaskSpec> {
     pub spec: S,
     pub parent: Option<CommandDispatcherContext>,
     pub tx: oneshot::Sender<Result<S::Output, S::Error>>,
+    pub cancellation_token: CancellationToken,
 }
