@@ -177,7 +177,7 @@ impl PixiEnvironmentSpec {
             .map_err(SolvePixiEnvironmentError::QueryError)
             .map_err(CommandDispatcherError::Failed)?;
         let total_records = binary_repodata.iter().map(RepoData::len).sum::<usize>();
-        tracing::info!(
+        tracing::debug!(
             "fetched {total_records} records in {:?}",
             fetch_repodata_start.elapsed()
         );
