@@ -23,8 +23,7 @@ use crate::{
     error::{DependencyError, GenericError},
     manifests::PackageManifest,
     toml::{
-        ExternalPackageProperties, ExternalWorkspaceProperties, FromTomlStr, PyProjectToml,
-        TomlManifest,
+        ExternalWorkspaceProperties, FromTomlStr, PackageDefaults, PyProjectToml, TomlManifest,
         pyproject::{TomlContact, TomlDependencyGroups, TomlProject},
     },
 };
@@ -260,30 +259,29 @@ impl PyProjectManifest {
             .map(PyProjectFields::from)
             .unwrap_or_default();
 
-        // TODO:  would be nice to add license, license-file, readme, homepage,
-        // repository, documentation, regarding the above, the types are a bit
-        // different than we expect, so the conversion is not straightforward we
-        // could change these types or we can convert. Let's decide when we make it.
-        // etc.
+        // Extract package defaults from [project] section
+        let package_defaults = PackageDefaults {
+            name: project.name.map(Spanned::take),
+            version: project
+                .version
+                .and_then(|v| v.take().to_string().parse().ok())
+                .or(poetry.version.and_then(|v| v.parse().ok())),
+            description: project
+                .description
+                .map(Spanned::take)
+                .or(poetry.description),
+            authors: project.authors.map(contacts_to_authors).or(poetry.authors),
+            license: None,
+            license_file: None,
+            readme: None,
+            homepage: None,
+            repository: None,
+            documentation: None,
+        };
+
         pixi.into_package_manifest(
-            ExternalPackageProperties {
-                name: project.name.map(Spanned::take),
-                version: project
-                    .version
-                    .and_then(|v| v.take().to_string().parse().ok())
-                    .or(poetry.version.and_then(|v| v.parse().ok())),
-                description: project
-                    .description
-                    .map(Spanned::take)
-                    .or(poetry.description),
-                authors: project.authors.map(contacts_to_authors).or(poetry.authors),
-                license: None,
-                license_file: None,
-                readme: None,
-                homepage: None,
-                repository: None,
-                documentation: None,
-            },
+            workspace.workspace_package_properties(),
+            package_defaults,
             workspace,
             root_directory,
         )
@@ -334,6 +332,34 @@ impl PyProjectManifest {
                 )
             })
             .collect();
+        // Extract and convert project authors to Vec<String> format for reuse
+        let project_authors = project
+            .authors
+            .map(contacts_to_authors)
+            .or(poetry.authors.clone());
+
+        // Extract package defaults from [project] section
+        let package_defaults = PackageDefaults {
+            name: project.name.as_ref().map(|name| name.value.clone()),
+            version: project
+                .version
+                .as_ref()
+                .and_then(|v| v.value.to_string().parse().ok())
+                .or(poetry.version.as_ref().and_then(|v| v.parse().ok())),
+            description: project
+                .description
+                .as_ref()
+                .map(|desc| desc.value.clone())
+                .or(poetry.description.clone()),
+            authors: project_authors.clone(),
+            license: None,
+            license_file: None,
+            readme: None,
+            homepage: None,
+            repository: None,
+            documentation: None,
+        };
+
         let (mut workspace_manifest, package_manifest, warnings) = pixi.into_workspace_manifest(
             ExternalWorkspaceProperties {
                 name: project.name.map(Spanned::take),
@@ -345,7 +371,7 @@ impl PyProjectManifest {
                     .description
                     .map(Spanned::take)
                     .or(poetry.description),
-                authors: project.authors.map(contacts_to_authors).or(poetry.authors),
+                authors: project_authors,
                 license: None,
                 license_file: None,
                 readme: None,
@@ -354,6 +380,7 @@ impl PyProjectManifest {
                 documentation: None,
                 features: implicit_pypi_features,
             },
+            package_defaults,
             root_directory,
         )?;
 
