@@ -2,19 +2,22 @@ import json
 import os
 import platform
 import shutil
+import sys
 import tomllib
 from pathlib import Path
 
 import pytest
-from syrupy.assertion import SnapshotAssertion
-from syrupy.matchers import path_type
+from dirty_equals import AnyThing, IsList, IsStr
+from inline_snapshot import snapshot
 
 from .common import (
+    CONDA_FORGE_CHANNEL,
     CURRENT_PLATFORM,
     EMPTY_BOILERPLATE_PROJECT,
     PIXI_VERSION,
     ExitCode,
     cwd,
+    find_commands_supporting_frozen_and_no_install,
     verify_cli_command,
 )
 
@@ -372,6 +375,19 @@ def test_pixi_init_non_existing_dir(pixi: Path, tmp_pixi_workspace: Path) -> Non
     assert "[workspace]" in manifest_content
 
 
+def test_pixi_init_pixi_home_parent(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    pixi_home = tmp_pixi_workspace / ".pixi"
+    pixi_home.mkdir(exist_ok=True)
+
+    verify_cli_command(
+        [pixi, "init", pixi_home.parent],
+        ExitCode.FAILURE,
+        # Test that we print a helpful error message
+        stderr_contains="pixi init",
+        env={"PIXI_HOME": str(pixi_home)},
+    )
+
+
 @pytest.mark.slow
 def test_pixi_init_pyproject(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest_path = tmp_pixi_workspace / "pyproject.toml"
@@ -775,6 +791,58 @@ def test_concurrency_flags(
     )
 
 
+def test_cli_config_options(
+    pixi: Path, tmp_pixi_workspace: Path, multiple_versions_channel_1: str
+) -> None:
+    manifest_path = tmp_pixi_workspace / "pixi.toml"
+
+    # Create a new project
+    verify_cli_command([pixi, "init", "--channel", multiple_versions_channel_1, tmp_pixi_workspace])
+
+    # Test --pinning-strategy flag
+    verify_cli_command(
+        [pixi, "add", "--pinning-strategy=semver", "--manifest-path", manifest_path, "package"]
+    )
+    verify_cli_command(
+        [pixi, "add", "--pinning-strategy=minor", "--manifest-path", manifest_path, "package2"]
+    )
+    verify_cli_command(
+        [pixi, "add", "--pinning-strategy=major", "--manifest-path", manifest_path, "package3"]
+    )
+    verify_cli_command(
+        [
+            pixi,
+            "add",
+            "--pinning-strategy=latest-up",
+            "--manifest-path",
+            manifest_path,
+            "package==0.1.0",
+        ]
+    )
+
+    # Test other CLI config flags
+    verify_cli_command(
+        [pixi, "install", "--run-post-link-scripts", "--manifest-path", manifest_path]
+    )
+    verify_cli_command([pixi, "install", "--tls-no-verify", "--manifest-path", manifest_path])
+    verify_cli_command(
+        [pixi, "install", "--use-environment-activation-cache", "--manifest-path", manifest_path]
+    )
+    verify_cli_command(
+        [pixi, "install", "--pypi-keyring-provider=disabled", "--manifest-path", manifest_path]
+    )
+    verify_cli_command(
+        [pixi, "install", "--pypi-keyring-provider=subprocess", "--manifest-path", manifest_path]
+    )
+
+    # Test --auth-file flag
+    auth_file = tmp_pixi_workspace / "auth.json"
+    auth_file.write_text("{}")
+    verify_cli_command(
+        [pixi, "install", f"--auth-file={auth_file}", "--manifest-path", manifest_path]
+    )
+
+
 def test_dont_add_broken_dep(pixi: Path, tmp_pixi_workspace: Path, dummy_channel_1: str) -> None:
     manifest_path = tmp_pixi_workspace / "pixi.toml"
 
@@ -1020,9 +1088,15 @@ def test_pixi_lock(pixi: Path, tmp_pixi_workspace: Path, dummy_channel_1: str) -
 
 @pytest.mark.extra_slow
 def test_pixi_auth(pixi: Path) -> None:
-    verify_cli_command([pixi, "auth", "login", "--token", "DUMMY_TOKEN", "https://prefix.dev/"])
     verify_cli_command(
-        [pixi, "auth", "login", "--token", "DUMMY_TOKEN", "https://repo.prefix.dev/"]
+        [pixi, "auth", "login", "--token", "DUMMY_TOKEN", "https://prefix.dev/"],
+        expected_exit_code=ExitCode.FAILURE,
+        stderr_contains="Unauthorized or invalid token",
+    )
+    verify_cli_command(
+        [pixi, "auth", "login", "--token", "DUMMY_TOKEN", "https://repo.prefix.dev/"],
+        expected_exit_code=ExitCode.FAILURE,
+        stderr_contains="Unauthorized or invalid token",
     )
     verify_cli_command(
         [pixi, "auth", "login", "--conda-token", "DUMMY_TOKEN", "https://conda.anaconda.org"]
@@ -1255,7 +1329,7 @@ def test_pixi_task_list_platforms(pixi: Path, tmp_pixi_workspace: Path) -> None:
     )
 
 
-def test_pixi_add_alias(pixi: Path, tmp_pixi_workspace: Path, snapshot: SnapshotAssertion) -> None:
+def test_pixi_add_alias(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
     toml = """
 [workspace]
@@ -1286,10 +1360,22 @@ platforms = ["linux-64", "win-64", "osx-64", "osx-arm64"]
         ]
     )
 
-    assert manifest.read_text() == snapshot
+    assert manifest.read_text() == snapshot("""\
+
+[workspace]
+name = "test"
+channels = []
+platforms = ["linux-64", "win-64", "osx-64", "osx-arm64"]
+
+[tasks]
+dummy-a = [{ task = "dummy-b" }, { task = "dummy-c" }]
+
+[target.linux-64.tasks]
+linux-alias = [{ task = "dummy-b" }, { task = "dummy-c" }]
+""")
 
 
-def test_pixi_add_task(pixi: Path, tmp_pixi_workspace: Path, snapshot: SnapshotAssertion) -> None:
+def test_pixi_add_task(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
     toml = """
 [workspace]
@@ -1317,12 +1403,20 @@ platforms = ["linux-64", "win-64", "osx-64", "osx-arm64"]
         [pixi, "task", "add", "--depends-on", "test", "--manifest-path", manifest, "test-alias", ""]
     )
 
-    assert manifest.read_text() == snapshot
+    assert manifest.read_text() == snapshot("""\
+
+[workspace]
+name = "test"
+channels = []
+platforms = ["linux-64", "win-64", "osx-64", "osx-arm64"]
+
+[tasks]
+test = { cmd = "echo 'Hello {{name | title}}'", args = ["name"] }
+test-alias = [{ task = "test" }]
+""")
 
 
-def test_pixi_task_list_json(
-    pixi: Path, tmp_pixi_workspace: Path, snapshot: SnapshotAssertion
-) -> None:
+def test_pixi_task_list_json(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
     toml = """
         [workspace]
@@ -1341,12 +1435,36 @@ def test_pixi_task_list_json(
 
     task_data = json.loads(result.stdout)
 
-    assert task_data == snapshot
+    assert task_data == snapshot(
+        [
+            {
+                "environment": "default",
+                "features": [
+                    {
+                        "name": "default",
+                        "tasks": [
+                            {
+                                "name": "test-task",
+                                "cmd": "echo 'Hello {{name | title}}'",
+                                "description": None,
+                                "depends_on": [],
+                                "args": [{"name": "name", "default": "World"}],
+                                "cwd": None,
+                                "env": None,
+                                "clean_env": False,
+                                "inputs": None,
+                                "outputs": None,
+                            }
+                        ],
+                    }
+                ],
+            }
+        ]
+    )
 
 
-def test_info_output_extended(
-    pixi: Path, tmp_pixi_workspace: Path, snapshot: SnapshotAssertion
-) -> None:
+@pytest.mark.extra_slow
+def test_info_output_extended(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
     toml = """
         [workspace]
@@ -1369,29 +1487,238 @@ def test_info_output_extended(
     )
     info_data = json.loads(result.stdout)
 
-    # Stub out path, size and other dynamic data from snapshot
-    path_matcher = path_type(
+    # Stub out path, size and other dynamic data from snapshot()
+    # samuelcolvin/dirty-equals#116
+    IsAnyList = IsList(length=...)  # type: ignore[call-overload]
+    assert info_data == snapshot(
         {
-            "auth_dir": (str,),
-            "cache_dir": (str,),
-            "cache_size": (str,),
-            "config_locations": (list,),
-            "environments_info.0.prefix": (str,),
-            "environments_info.0.environment_size": (str,),
-            "environments_info.0.platforms": (list,),
-            "environments_info.1.prefix": (str,),
-            "environments_info.1.environment_size": (str,),
-            "environments_info.1.platforms": (list,),
-            "global_info.bin_dir": (str,),
-            "global_info.env_dir": (str,),
-            "global_info.manifest": (str,),
-            "platform": (str,),
-            "project_info.manifest_path": (str,),
-            "project_info.pixi_folder_size": (str,),
-            "project_info.last_updated": (str,),
-            "version": (str,),
-            "virtual_packages": (list,),
+            "platform": IsStr,
+            "virtual_packages": IsAnyList,
+            "version": IsStr,
+            "cache_dir": IsStr,
+            "cache_size": AnyThing,
+            "auth_dir": IsStr,
+            "global_info": {
+                "bin_dir": IsStr,
+                "env_dir": IsStr,
+                "manifest": IsStr,
+            },
+            "project_info": {
+                "name": "test",
+                "manifest_path": IsStr,
+                "last_updated": IsStr,
+                "pixi_folder_size": IsStr,
+                "version": None,
+            },
+            "environments_info": [
+                {
+                    "name": "default",
+                    "features": ["default"],
+                    "solve_group": None,
+                    "environment_size": IsStr,
+                    "dependencies": [],
+                    "pypi_dependencies": [],
+                    "platforms": IsAnyList,
+                    "tasks": [],
+                    "channels": ["conda-forge"],
+                    "prefix": IsStr,
+                    "system_requirements": {
+                        "macos": None,
+                        "linux": None,
+                        "cuda": None,
+                        "libc": None,
+                        "archspec": None,
+                    },
+                },
+                {
+                    "name": "py312",
+                    "features": ["py312", "default"],
+                    "solve_group": None,
+                    "environment_size": IsStr,
+                    "dependencies": ["python"],
+                    "pypi_dependencies": [],
+                    "platforms": IsAnyList,
+                    "tasks": [],
+                    "channels": ["conda-forge"],
+                    "prefix": IsStr,
+                    "system_requirements": {
+                        "macos": None,
+                        "linux": None,
+                        "cuda": None,
+                        "libc": None,
+                        "archspec": None,
+                    },
+                },
+            ],
+            "config_locations": IsAnyList,
         }
     )
 
-    assert info_data == snapshot(matcher=path_matcher)
+
+@pytest.mark.skipif(
+    sys.platform.startswith("win"),
+    reason="Fish shell is not supported on Windows",
+)
+@pytest.mark.slow
+def test_fish_completions(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    manifest = tmp_pixi_workspace.joinpath("pixi.toml")
+    toml = f"""
+[workspace]
+name = "test"
+channels = ["{CONDA_FORGE_CHANNEL}"]
+platforms = ["{CURRENT_PLATFORM}"]
+        """
+    manifest.write_text(toml)
+    # install fish
+    verify_cli_command([pixi, "add", "fish", "--manifest-path", tmp_pixi_workspace])
+
+    # Verify that the shell hook generates the correct completions
+    output = verify_cli_command([pixi, "completion", "--shell", "fish"])
+    out = output.stdout
+    # write output to file
+    fish_completion_file = tmp_pixi_workspace / "pixi.fish"
+    fish_completion_file.write_text(out)
+
+    # Check that the file can be parsed by fish
+    verify_cli_command(
+        [
+            pixi,
+            "run",
+            "--manifest-path",
+            tmp_pixi_workspace,
+            "fish",
+            "-c",
+            f"source {fish_completion_file}",
+        ],
+    )
+
+
+@pytest.mark.slow
+def test_frozen_no_install_invariant(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    """Test that --frozen --no-install maintains lockfile invariant and keeps conda-meta empty.
+    This test is made up out of two parts:
+
+    1. This test verifies that when using --frozen --no-install flags together, the pixi.lock
+    file does not change and the conda-meta directory stays empty across all commands that
+    support these flags.
+    2. It discovers all documented commands that support both --frozen and --no-install flags
+    and checks that they are included in the test. If any command is missing, it fails
+    with a message to add it to the test list.
+    """
+    manifest_path = tmp_pixi_workspace / "pixi.toml"
+    lock_file_path = tmp_pixi_workspace / "pixi.lock"
+    conda_meta_path = tmp_pixi_workspace / ".pixi" / "envs" / "default" / "conda-meta"
+
+    # Common flags for frozen no-install operations
+    frozen_no_install_flags: list[str | Path] = [
+        "--manifest-path",
+        manifest_path,
+        "--frozen",
+        "--no-install",
+    ]
+
+    # Create a new project with bzip2 (lightweight package)
+    verify_cli_command([pixi, "init", tmp_pixi_workspace], ExitCode.SUCCESS)
+    # Add bzip2 package to keep installation time low
+    verify_cli_command([pixi, "add", "--manifest-path", manifest_path, "bzip2"])
+
+    # Create a simple environment.yml file for import testing
+    simple_env_yml = tmp_pixi_workspace / "simple_env.yml"
+    simple_env_yml.write_text("""name: simple-env
+channels:
+  - conda-forge
+dependencies:
+  - sdl2
+""")
+
+    # Store the original lockfile content
+    original_lock_content = lock_file_path.read_text()
+
+    # Remove conda-meta folder to simulate something that would normally trigger an install
+    if conda_meta_path.exists():
+        shutil.rmtree(conda_meta_path)
+
+    # Helper function to check if the invariants hold after a command execution
+    def check_invariants(command_name: str) -> None:
+        # Check that lockfile hasn't changed
+        current_lock_content = lock_file_path.read_text()
+        assert current_lock_content == original_lock_content, (
+            f"Lockfile changed after {command_name} with --frozen --no-install"
+        )
+
+        # Check that conda-meta directory stays empty/non-existent
+        assert not conda_meta_path.exists() or not any(conda_meta_path.iterdir()), (
+            f"conda-meta directory not empty after {command_name} with --frozen --no-install"
+        )
+
+    # Test commands that properly respect --frozen --no-install
+    # Define commands as (command_parts, additional_args, command_name_for_invariants)
+    commands_to_test: list[tuple[list[str], list[str], str]] = [
+        # Let's start with adding a workspace channel because that would trigger a re-solve in most cases
+        # Don't move this!
+        (
+            ["workspace", "channel", "add"],
+            ["https://prefix.dev/bioconda"],
+            "pixi workspace channel add",
+        ),
+    ]
+    commands_to_test += [
+        (["list"], [], "pixi list"),
+        (["tree"], [], "pixi tree"),
+        (["shell-hook"], [], "pixi shell-hook"),
+        # Special case: pixi shell uses --locked instead of --frozen and expects failure
+        (["shell"], [], "pixi shell"),
+        # Test manifest modifications with --frozen --no-install (these should work)
+        # Note: These modify manifest but not lockfile due to --frozen
+        (["add"], ["python"], "pixi add"),
+        (["remove"], ["python"], "pixi remove"),
+        (["run"], ["echo", "test"], "pixi run"),
+        # Export commands - use temporary directory
+        (
+            ["workspace", "export", "conda-explicit-spec"],
+            [str(tmp_pixi_workspace / "export_test")],
+            "pixi workspace export conda-explicit-spec",
+        ),
+        # Upgrade commands
+        (["upgrade"], [], "pixi upgrade"),
+    ]
+    # This command needs to stay last so we always have something that requires a re-solve
+    # Dont move this!
+    commands_to_test.append(
+        (
+            ["workspace", "channel", "remove"],
+            ["https://prefix.dev/bioconda"],
+            "pixi workspace channel remove",
+        )
+    )
+
+    # Execute all commands and check invariants
+    for command_parts, additional_args, command_name in commands_to_test:
+        if command_name == "pixi shell":
+            # Special case: shell uses --locked instead of --frozen and expects failure
+            verify_cli_command(
+                [pixi, "shell", "--manifest-path", manifest_path, "--locked", "--no-install"],
+                expected_exit_code=ExitCode.FAILURE,
+            )
+        else:
+            verify_cli_command([pixi, *command_parts, *frozen_no_install_flags, *additional_args])
+        check_invariants(command_name)
+
+    # Discover all commands that support --frozen and --no-install flags
+    supported_commands = find_commands_supporting_frozen_and_no_install()
+
+    # Extract commands being tested from the test list
+    tested_commands = {command_name for _, _, command_name in commands_to_test}
+
+    # Find commands that support the flags but aren't being tested
+    missing_commands = set(supported_commands) - tested_commands
+
+    if missing_commands:
+        missing_list = "\n  - ".join(sorted(missing_commands))
+        pytest.fail(
+            f"Found {len(missing_commands)} command(s) that support --frozen --no-install "
+            f"but are not included in the test:\n  - {missing_list}\n\n"
+            f"Please add these commands to the commands_to_test list in test_frozen_no_install_invariant "
+            f"to ensure comprehensive coverage.\n"
+            f"If you get here you know all commands that *are* supported correctly listen to --frozen and --no-install flags."
+        )
