@@ -1,18 +1,24 @@
 import json
-import tomli_w
+import os
+import shutil
+import signal
+import subprocess
+import sys
+import tempfile
+import time
 from pathlib import Path
 
+import pytest
+import tomli
+import tomli_w
+
 from .common import (
     EMPTY_BOILERPLATE_PROJECT,
-    verify_cli_command,
     ExitCode,
     default_env_path,
+    verify_cli_command,
 )
 
-import tempfile
-import os
-import tomli
-
 
 def test_run_in_shell_environment(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
@@ -179,50 +185,6 @@ def test_using_prefix_validation(
         assert Path(file).exists()
 
 
-def test_prefix_revalidation(pixi: Path, tmp_pixi_workspace: Path, dummy_channel_1: str) -> None:
-    manifest = tmp_pixi_workspace.joinpath("pixi.toml")
-    toml = f"""
-    [project]
-    name = "test"
-    channels = ["{dummy_channel_1}"]
-    platforms = ["linux-64", "osx-64", "osx-arm64", "win-64"]
-
-    [dependencies]
-    dummy-a = "*"
-    """
-    manifest.write_text(toml)
-
-    # Run the installation
-    verify_cli_command(
-        [pixi, "install", "--manifest-path", manifest],
-    )
-
-    # Validate creation of the pixi file with the hash
-    pixi_file = default_env_path(tmp_pixi_workspace).joinpath("conda-meta").joinpath("pixi")
-    assert pixi_file.exists()
-    assert "environment_lock_file_hash" in pixi_file.read_text()
-
-    # Break environment on purpose
-    dummy_a_meta_files = (
-        default_env_path(tmp_pixi_workspace).joinpath("conda-meta").glob("dummy-a*.json")
-    )
-
-    for file in dummy_a_meta_files:
-        path = Path(file)
-        if path.exists():
-            path.unlink()  # Removes the file
-
-    # Run with revalidation to force reinstallation
-    verify_cli_command(
-        [pixi, "run", "--manifest-path", manifest, "--revalidate", "echo", "hello"],
-        stdout_contains="hello",
-    )
-
-    # Validate that the dummy-a files are reinstalled
-    for file in dummy_a_meta_files:
-        assert Path(file).exists()
-
-
 def test_run_with_activation(pixi: Path, tmp_pixi_workspace: Path) -> None:
     manifest = tmp_pixi_workspace.joinpath("pixi.toml")
     toml = f"""
@@ -618,7 +580,11 @@ def test_task_with_dependency_args(pixi: Path, tmp_pixi_workspace: Path) -> None
                 {"arg": "arg2", "default": "default2"},
             ],
         },
-        "parent-task": {"depends-on": [{"task": "base-task", "args": ["custom1", "custom2"]}]},
+        "parent-task": {
+            "depends-on": [
+                {"task": "base-task", "args": [{"arg1": "custom1"}, {"arg2": "custom2"}]}
+            ]
+        },
         "parent-task-partial": {"depends-on": [{"task": "base-task", "args": ["override1"]}]},
     }
 
@@ -635,6 +601,94 @@ def test_task_with_dependency_args(pixi: Path, tmp_pixi_workspace: Path) -> None
     )
 
 
+def test_named_dependency_args_valid(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    """Test passing named arguments to a dependency task."""
+    manifest_path = tmp_pixi_workspace.joinpath("pixi.toml")
+
+    manifest_content = tomli.loads(EMPTY_BOILERPLATE_PROJECT)
+
+    manifest_content["tasks"] = {
+        "base-task": {
+            "cmd": "echo Base task with {{ arg1 }}, {{ arg2 }}, and {{ arg3 }}",
+            "args": [
+                {"arg": "arg1"},
+                {"arg": "arg2", "default": "default2"},
+                {"arg": "arg3", "default": "default3"},
+            ],
+        },
+        # named args can be passed in any order, and default values are used
+        "valid1": {
+            "depends-on": [
+                {"task": "base-task", "args": [{"arg2": "custom2"}, {"arg1": "custom1"}]}
+            ]
+        },
+        # positional args before named args should be fine, and default values can fill in gaps
+        "valid2": {"depends-on": [{"task": "base-task", "args": ["custom1", {"arg3": "custom3"}]}]},
+    }
+
+    manifest_path.write_text(tomli_w.dumps(manifest_content))
+
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "valid1"],
+        stdout_contains="Base task with custom1, custom2, and default3",
+    )
+
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "valid2"],
+        stdout_contains="Base task with custom1, default2, and custom3",
+    )
+
+
+def test_named_dependency_args_invalid(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    """Test passing named arguments to a dependency task."""
+    manifest_path = tmp_pixi_workspace.joinpath("pixi.toml")
+
+    manifest_content = tomli.loads(EMPTY_BOILERPLATE_PROJECT)
+
+    manifest_content["tasks"] = {
+        "base-task": {
+            "cmd": "echo Base task with {{ arg1 }}, {{ arg2 }}, and {{ arg3 }}",
+            "args": [
+                {"arg": "arg1"},
+                {"arg": "arg2", "default": "default2"},
+                {"arg": "arg3", "default": "default3"},
+            ],
+        },
+        # unknown args should error
+        "invalid1": {"depends-on": [{"task": "base-task", "args": ["custom1", {"foo": "bar"}]}]},
+        # positional args after named args should error
+        "invalid2": {
+            "depends-on": [{"task": "base-task", "args": [{"arg2": "custom2"}, "custom1"]}]
+        },
+        # args without a default value cannot be omitted
+        "invalid3": {
+            "depends-on": [
+                {"task": "base-task", "args": [{"arg2": "custom2"}, {"arg3": "custom3"}]}
+            ]
+        },
+    }
+
+    manifest_path.write_text(tomli_w.dumps(manifest_content))
+
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "invalid1"],
+        ExitCode.FAILURE,
+        stderr_contains="'foo' does not exist",
+    )
+
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "invalid2"],
+        ExitCode.FAILURE,
+        stderr_contains="Positional argument 'custom1' found after named argument",
+    )
+
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest_path, "invalid3"],
+        ExitCode.FAILURE,
+        stderr_contains="no value provided for argument 'arg1'",
+    )
+
+
 def test_complex_task_dependencies_with_args(pixi: Path, tmp_pixi_workspace: Path) -> None:
     """Test complex task dependencies with arguments."""
     manifest_path = tmp_pixi_workspace.joinpath("pixi.toml")
@@ -1355,3 +1409,88 @@ def test_task_caching_with_multiple_inputs_args(pixi: Path, tmp_pixi_workspace:
             "cache hit",
         ],
     )
+
+
+def test_shell_quoting_run_commands(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    """Test that shell quoting works correctly for CLI commands with quotes.
+
+    This test addresses GitHub issue #1979 where pixi run required multiple
+    layers of quoting to avoid shell substitution.
+    """
+    manifest = tmp_pixi_workspace.joinpath("pixi.toml")
+    manifest.write_text(EMPTY_BOILERPLATE_PROJECT)
+
+    # Test Python command with single quotes inside double quotes
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest, "python", "-c", "print('hello world')"],
+        stdout_contains="hello world",
+    )
+
+    # Test Python command with double quotes inside single quotes
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest, "python", "-c", 'print("hello world")'],
+        stdout_contains="hello world",
+    )
+
+    # Test Python command with escaped quotes
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest, "python", "-c", 'print("hello world")'],
+        stdout_contains="hello world",
+    )
+
+    # Test echo command with quotes
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest, "echo", "hello world"],
+        stdout_contains="hello world",
+    )
+
+    # Test command with arguments containing spaces
+    verify_cli_command(
+        [pixi, "run", "--manifest-path", manifest, "echo", "hello", "world", "with spaces"],
+        stdout_contains="hello world with spaces",
+    )
+
+
+@pytest.mark.skipif(
+    sys.platform == "win32",
+    reason="Signal handling is different on Windows",
+)
+def test_signal_forwarding(pixi: Path, tmp_pixi_workspace: Path) -> None:
+    """Test that signals are forwarded correctly to the task."""
+
+    # copy the folder from ../data/run_signals to the tmp workspace
+    data_path = Path(__file__).parent.parent.joinpath("data", "run_signals")
+    tmp_data_path = tmp_pixi_workspace.joinpath("run_signals")
+
+    shutil.copytree(data_path, tmp_data_path)
+
+    # Use the manifest from the copied run_signals directory
+    manifest = tmp_data_path.joinpath("pixi.toml")
+
+    # install the dependencies
+    subprocess.check_call([pixi, "install", "--manifest-path", manifest], cwd=tmp_data_path)
+    # run the `start` task in the background and send some signals to it
+    process = subprocess.Popen(
+        [pixi, "run", "--manifest-path", manifest, "start"], cwd=tmp_data_path
+    )
+
+    time.sleep(1)  # wait for the process to start
+
+    # send a SIGINT to the process
+    process.send_signal(signal.SIGINT)
+
+    # check exit code
+    exit_code = process.wait(timeout=10)
+    assert exit_code == 12, f"Process exited with code {exit_code}"
+
+    output_file = tmp_data_path.joinpath("output.txt")
+
+    if output_file.exists():
+        # check if we can read "SIGINT received, exiting gracefully"
+        with open(output_file, "r") as f:
+            output = f.read()
+            assert "SIGINT received, exiting gracefully" in output, (
+                "SIGINT signal was not handled correctly"
+            )
+    else:
+        raise AssertionError("Output file was not created")
