@@ -7,19 +7,20 @@ use std::{
 };
 
 use fs_err::tokio as tokio_fs;
-use pixi::{
+use pixi_cli::run::{self, Args};
+use pixi_cli::{
+    LockFileUsageConfig,
+    cli_config::{LockAndInstallConfig, LockFileUpdateConfig, WorkspaceConfig},
+};
+use pixi_config::{Config, DetachedEnvironments};
+use pixi_consts::consts;
+use pixi_core::InstallFilter;
+use pixi_core::{
     UpdateLockFileOptions, Workspace,
-    cli::{
-        LockFileUsageConfig,
-        cli_config::{LockFileUpdateConfig, WorkspaceConfig},
-        run::{self, Args},
-    },
     environment::LockFileUsage,
     lock_file::{CondaPrefixUpdater, ReinstallPackages, UpdateMode},
     workspace::{HasWorkspaceRef, grouped_environment::GroupedEnvironment},
 };
-use pixi_config::{Config, DetachedEnvironments};
-use pixi_consts::consts;
 use pixi_manifest::{FeatureName, FeaturesExt};
 use pixi_record::PixiRecord;
 use rattler_conda_types::{Platform, RepoDataRecord};
@@ -28,21 +29,25 @@ use tempfile::{TempDir, tempdir};
 use tokio::{fs, task::JoinSet};
 use url::Url;
 use uv_configuration::RAYON_INITIALIZE;
+use uv_pep508::PackageName;
 use uv_python::PythonEnvironment;
 
 use crate::common::{
     LockFileExt, PixiControl,
     builders::{
-        HasDependencyConfig, HasLockFileUpdateConfig, HasPrefixUpdateConfig, string_from_iter,
+        HasDependencyConfig, HasLockFileUpdateConfig, HasNoInstallConfig, string_from_iter,
     },
     package_database::{Package, PackageDatabase},
 };
+use crate::setup_tracing;
 
 /// Should add a python version to the environment and lock file that matches
 /// the specified version and run it
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn install_run_python() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     pixi.add("python==3.11.0").with_install(true).await.unwrap();
@@ -90,6 +95,8 @@ async fn install_run_python() {
 /// solution to keep using version `1` of bar.
 #[tokio::test]
 async fn test_incremental_lock_file() {
+    setup_tracing();
+
     let mut package_database = PackageDatabase::default();
 
     // Add a package `foo` that depends on `bar` both set to version 1.
@@ -170,6 +177,8 @@ async fn test_incremental_lock_file() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn install_locked_with_config() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
 
@@ -202,7 +211,8 @@ async fn install_locked_with_config() {
 
     // Add new version of python only to the manifest
     pixi.add("python==3.9.0")
-        .without_lockfile_update()
+        .with_frozen(true)
+        .with_install(false)
         .await
         .unwrap();
 
@@ -269,6 +279,8 @@ async fn install_locked_with_config() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn install_frozen() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     // Add and update lockfile with this version of python
@@ -276,7 +288,8 @@ async fn install_frozen() {
 
     // Add new version of python only to the manifest
     pixi.add("python==3.10.1")
-        .without_lockfile_update()
+        .with_frozen(true)
+        .with_install(false)
         .await
         .unwrap();
 
@@ -293,9 +306,12 @@ async fn install_frozen() {
     // Check if running with frozen doesn't suddenly install the latest update.
     let result = pixi
         .run(run::Args {
-            lock_file_update_config: LockFileUpdateConfig {
-                lock_file_usage: LockFileUsageConfig {
-                    frozen: true,
+            lock_and_install_config: LockAndInstallConfig {
+                lock_file_update_config: LockFileUpdateConfig {
+                    lock_file_usage: LockFileUsageConfig {
+                        frozen: true,
+                        ..Default::default()
+                    },
                     ..Default::default()
                 },
                 ..Default::default()
@@ -322,9 +338,97 @@ fn create_uv_environment(prefix: &Path, cache: &uv_cache::Cache) -> PythonEnviro
     uv_python::PythonEnvironment::from_interpreter(interpreter)
 }
 
+// Helper to check if a pypi package is installed.
+fn is_pypi_package_installed(env: &PythonEnvironment, package_name: &str) -> bool {
+    let site_packages = uv_installer::SitePackages::from_environment(env).unwrap();
+    let found_packages = site_packages.get_packages(&PackageName::from_str(package_name).unwrap());
+    !found_packages.is_empty()
+}
+
+// Helper to check if a conda package is installed.
+async fn is_conda_package_installed(prefix_path: &Path, package_name: &str) -> bool {
+    let conda_prefix = pixi_utils::prefix::Prefix::new(prefix_path.to_path_buf());
+    conda_prefix
+        .find_designated_package(&rattler_conda_types::PackageName::try_from(package_name).unwrap())
+        .await
+        .is_ok()
+}
+
+/// Test `pixi install --frozen --skip` functionality
+#[tokio::test]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn install_frozen_skip() {
+    setup_tracing();
+
+    // Create a project with a local python dependency 'no-build-editable'
+    // and a local conda dependency 'python_rich'
+    let current_platform = Platform::current();
+    let manifest = format!(
+        r#"
+        [workspace]
+        channels = ["conda-forge"]
+        description = "Add a short description here"
+        name = "pyproject"
+        platforms = ["{platform}"]
+        preview = ["pixi-build"]
+        version = "0.1.0"
+
+        [dependencies]
+        python = "*"
+        python_rich = {{ path = "./python" }}
+
+        [pypi-dependencies]
+        no-build-editable = {{ path = "./no-build-editable" }}
+        "#,
+        platform = current_platform,
+    );
+
+    let pixi = PixiControl::from_manifest(&manifest).expect("cannot instantiate pixi project");
+
+    let workspace_root = PathBuf::from(env!("CARGO_WORKSPACE_DIR"));
+
+    fs_extra::dir::copy(
+        workspace_root.join("docs/source_files/pixi_workspaces/pixi_build/python"),
+        pixi.workspace_path(),
+        &fs_extra::dir::CopyOptions::new(),
+    )
+    .unwrap();
+
+    fs_extra::dir::copy(
+        workspace_root.join("tests/data/satisfiability/no-build-editable"),
+        pixi.workspace_path(),
+        &fs_extra::dir::CopyOptions::new(),
+    )
+    .unwrap();
+
+    pixi.update_lock_file().await.unwrap();
+
+    // Check that neither 'python_rich' nor 'no-build-editable' are installed when skipped
+    pixi.install()
+        .with_frozen()
+        .with_skipped(vec!["no-build-editable".into(), "python_rich".into()])
+        .await
+        .unwrap();
+
+    let prefix_path = pixi.default_env_path().unwrap();
+    let cache = uv_cache::Cache::temp().unwrap();
+    let env = create_uv_environment(&prefix_path, &cache);
+
+    assert!(!is_pypi_package_installed(&env, "no-build-editable"));
+    assert!(!is_conda_package_installed(&prefix_path, "python_rich").await);
+
+    // Check that 'no-build-editable' and 'python_rich' are installed after a followup normal install
+    pixi.install().with_frozen().await.unwrap();
+
+    assert!(is_pypi_package_installed(&env, "no-build-editable"));
+    assert!(is_conda_package_installed(&prefix_path, "python_rich").await);
+}
+
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn pypi_reinstall_python() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     // Add and update lockfile with this version of python
@@ -333,7 +437,7 @@ async fn pypi_reinstall_python() {
     // Add flask from pypi
     pixi.add("flask")
         .with_install(true)
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .await
         .unwrap();
     assert!(pixi.lock_file().await.unwrap().contains_match_spec(
@@ -381,6 +485,8 @@ async fn pypi_reinstall_python() {
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 // Check if we add and remove a pypi package that the site-packages is cleared
 async fn pypi_add_remove() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     // Add and update lockfile with this version of python
@@ -389,7 +495,7 @@ async fn pypi_add_remove() {
     // Add flask from pypi
     pixi.add("flask[dotenv]")
         .with_install(true)
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .await
         .unwrap();
 
@@ -403,7 +509,7 @@ async fn pypi_add_remove() {
     assert!(installed_311.iter().count() > 0);
 
     pixi.remove("flask[dotenv]")
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -414,6 +520,8 @@ async fn pypi_add_remove() {
 
 #[tokio::test]
 async fn test_channels_changed() {
+    setup_tracing();
+
     // Write a channel with a package `bar` with only one version
     let mut package_database_a = PackageDatabase::default();
     package_database_a.add_package(Package::build("bar", "2").finish());
@@ -469,6 +577,8 @@ async fn test_channels_changed() {
 
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 async fn install_conda_meta_history() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     pixi.install().await.unwrap();
@@ -482,6 +592,8 @@ async fn install_conda_meta_history() {
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn minimal_lockfile_update_pypi() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
 
@@ -490,7 +602,7 @@ async fn minimal_lockfile_update_pypi() {
 
     // Add pypi dependencies which are not the latest options
     pixi.add_multiple(vec!["uvicorn==0.28.0", "click==7.1.2"])
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -505,7 +617,7 @@ async fn minimal_lockfile_update_pypi() {
 
     // Widening the click version to allow for the latest version
     pixi.add_multiple(vec!["uvicorn==0.29.0", "click"])
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -526,13 +638,15 @@ async fn minimal_lockfile_update_pypi() {
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_installer_name() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
 
     // Add and update lockfile with this version of python
     pixi.add("python==3.11").with_install(true).await.unwrap();
     pixi.add("click==8.0.0")
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -557,7 +671,7 @@ async fn test_installer_name() {
     fs_err::write(dist_info.join("INSTALLER"), "not-pixi").unwrap();
     pixi.remove("click==8.0.0")
         .with_install(true)
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .await
         .unwrap();
 
@@ -571,7 +685,7 @@ async fn test_installer_name() {
 
     // re-manage the package by adding it, this should cause a reinstall
     pixi.add("click==8.0.0")
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -586,13 +700,18 @@ async fn test_installer_name() {
 /// Makes sure the lockfile isn't touched and the environment is still
 /// installed.
 async fn test_old_lock_install() {
-    let lock_str =
-        fs_err::read_to_string("tests/data/satisfiability/old_lock_file/pixi.lock").unwrap();
-    let project = Workspace::from_path(Path::new(
-        "tests/data/satisfiability/old_lock_file/pyproject.toml",
-    ))
+    setup_tracing();
+
+    let workspace_root = PathBuf::from(env!("CARGO_WORKSPACE_DIR"));
+    let lock_str = fs_err::read_to_string(
+        workspace_root.join("tests/data/satisfiability/old_lock_file/pixi.lock"),
+    )
     .unwrap();
-    pixi::environment::get_update_lock_file_and_prefix(
+    let project = Workspace::from_path(
+        &workspace_root.join("tests/data/satisfiability/old_lock_file/pyproject.toml"),
+    )
+    .unwrap();
+    pixi_core::environment::get_update_lock_file_and_prefix(
         &project.default_environment(),
         UpdateMode::Revalidate,
         UpdateLockFileOptions {
@@ -601,18 +720,24 @@ async fn test_old_lock_install() {
             ..Default::default()
         },
         ReinstallPackages::default(),
+        &InstallFilter::default(),
     )
     .await
     .unwrap();
     assert_eq!(
         lock_str,
-        fs_err::read_to_string("tests/data/satisfiability/old_lock_file/pixi.lock").unwrap()
+        fs_err::read_to_string(
+            workspace_root.join("tests/data/satisfiability/old_lock_file/pixi.lock")
+        )
+        .unwrap()
     );
 }
 
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_no_build_isolation() {
+    setup_tracing();
+
     let current_platform = Platform::current();
     let setup_py = r#"
 from setuptools import setup, find_packages
@@ -683,9 +808,125 @@ setup(
     pixi.install().await.expect("cannot install project");
 }
 
+#[tokio::test(flavor = "multi_thread", worker_threads = 1)]
+#[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
+async fn test_no_build_isolation_with_dependencies() {
+    setup_tracing();
+
+    let current_platform = Platform::current();
+
+    // Create pyproject.toml for package-tdjager (will be installed with build isolation)
+    let pyproject_toml_a = r#"
+[build-system]
+requires = ["setuptools>=45", "wheel"]
+build-backend = "setuptools.build_meta"
+
+[project]
+name = "package-tdjager"
+version = "0.1.0"
+description = "Package Tim de Jager for testing build isolation"
+authors = [{name = "Test Author"}]
+requires-python = ">=3.6"
+dependencies = []
+    "#;
+
+    // Create pyproject.toml for package-b (will be installed WITHOUT build isolation)
+    // package-b depends on package-tdjager at build time
+    let pyproject_toml_b = r#"
+[build-system]
+requires = ["setuptools>=45", "wheel", "package-tdjager"]
+build-backend = "setuptools.build_meta"
+
+[project]
+name = "package-b"
+version = "0.1.0"
+description = "Package B that depends on Package Tim de Jager during build"
+authors = [{name = "Test Author"}]
+requires-python = ">=3.6"
+dependencies = []
+    "#;
+
+    let manifest = format!(
+        r#"
+        [project]
+        name = "no-build-isolation-deps"
+        channels = ["https://prefix.dev/conda-forge"]
+        platforms = ["{platform}"]
+
+        [pypi-options]
+        no-build-isolation = ["package-b"]
+
+        [dependencies]
+        python = "3.12.*"
+        setuptools = ">=72,<73"
+
+        [pypi-dependencies.package-b]
+        path = "./package-b"
+
+        [pypi-dependencies.package-tdjager]
+        path = "./package-tdjager"
+
+        "#,
+        platform = current_platform,
+    );
+
+    let pixi = PixiControl::from_manifest(&manifest).expect("cannot instantiate pixi project");
+
+    let project_path = pixi.workspace_path();
+
+    // Create package-tdjager directory and pyproject.toml
+    let package_a_dir = project_path.join("package-tdjager");
+    fs_err::create_dir_all(&package_a_dir).unwrap();
+    fs_err::write(package_a_dir.join("pyproject.toml"), pyproject_toml_a).unwrap();
+
+    // Create empty __init__.py for package-tdjager
+    let package_a_pkg_dir = package_a_dir.join("package_tdjager");
+    fs_err::create_dir_all(&package_a_pkg_dir).unwrap();
+    fs_err::write(package_a_pkg_dir.join("__init__.py"), "").unwrap();
+
+    // Create setup.py for package-b that imports package-tdjager at build time
+    let setup_py_b = r#"
+from setuptools import setup
+
+import package_tdjager
+
+setup(
+    name="package-b",
+    version="0.1.0",
+    description="Package B that depends on Package Tim de Jager during build",
+    author="Test Author",
+    python_requires=">=3.6",
+    install_requires=[],
+    setup_requires=["package-tdjager"],
+)
+    "#;
+
+    // Create package-b directory, setup.py and pyproject.toml
+    let package_b_dir = project_path.join("package-b");
+    fs_err::create_dir_all(&package_b_dir).unwrap();
+    fs_err::write(package_b_dir.join("pyproject.toml"), pyproject_toml_b).unwrap();
+    fs_err::write(package_b_dir.join("setup.py"), setup_py_b).unwrap();
+
+    // Create empty __init__.py for package-b
+    let package_b_pkg_dir = package_b_dir.join("package_b");
+    fs_err::create_dir_all(&package_b_pkg_dir).unwrap();
+    fs_err::write(package_b_pkg_dir.join("__init__.py"), "").unwrap();
+
+    // This should succeed with the 3-step installation:
+    // 1. Conda packages (python, setuptools)
+    // 2. PyPI packages with build isolation (package-tdjager) - batch
+    // 3. PyPI packages without build isolation (package-b) - one by one
+    // The key test: package-b should be able to import package-tdjager during its build
+    pixi.install()
+        .await
+        .expect("cannot install project with no-build-isolation dependencies");
+}
+
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_setuptools_override_failure() {
+    setup_tracing();
+
     // This was causing issues like: https://github.com/prefix-dev/pixi/issues/1686
     let manifest = format!(
         r#"
@@ -718,6 +959,8 @@ async fn test_setuptools_override_failure() {
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_many_linux_wheel_tag() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     #[cfg(not(target_os = "linux"))]
     pixi.init_with_platforms(vec![
@@ -732,7 +975,7 @@ async fn test_many_linux_wheel_tag() {
     pixi.add("python==3.12.*").await.unwrap();
     // We know that this package has many linux wheel tags for this version
     pixi.add("gmsh==4.13.1")
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         .with_install(true)
         .await
         .unwrap();
@@ -741,6 +984,8 @@ async fn test_many_linux_wheel_tag() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_ensure_gitignore_file_creation() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
     let gitignore_path = pixi.workspace().unwrap().pixi_dir().join(".gitignore");
@@ -793,6 +1038,8 @@ async fn test_ensure_gitignore_file_creation() {
 #[tokio::test(flavor = "multi_thread", worker_threads = 1)]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn pypi_prefix_is_not_created_when_whl() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init().await.unwrap();
 
@@ -801,7 +1048,7 @@ async fn pypi_prefix_is_not_created_when_whl() {
 
     // Add pypi dependency that is a wheel
     pixi.add_multiple(vec!["boltons==24.1.0"])
-        .set_type(pixi::DependencyType::PypiDependency)
+        .set_type(pixi_core::DependencyType::PypiDependency)
         // we don't want to install the package
         // we just want to check that the prefix is not created
         .with_install(false)
@@ -832,6 +1079,8 @@ async fn pypi_prefix_is_not_created_when_whl() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn conda_pypi_override_correct_per_platform() {
+    setup_tracing();
+
     let pixi = PixiControl::new().unwrap();
     pixi.init_with_platforms(vec![
         Platform::OsxArm64.to_string(),
@@ -887,6 +1136,8 @@ async fn conda_pypi_override_correct_per_platform() {
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 
 async fn test_multiple_prefix_update() {
+    setup_tracing();
+
     let current_platform = Platform::current();
     let virtual_packages = VirtualPackages::detect(&VirtualPackageOverrides::default())
         .unwrap()
@@ -994,7 +1245,7 @@ async fn test_multiple_prefix_update() {
         let pixi_records = pixi_records.clone();
         // tasks.push(conda_prefix_updater.update(pixi_records));
         let updater = conda_prefix_updater.clone();
-        sets.spawn(async move { updater.update(pixi_records, None).await.cloned() });
+        sets.spawn(async move { updater.update(pixi_records, None, None).await.cloned() });
     }
 
     let mut first_modified = None;
@@ -1027,6 +1278,8 @@ async fn test_multiple_prefix_update() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn install_s3() {
+    setup_tracing();
+
     let r2_access_key_id = std::env::var("PIXI_TEST_R2_ACCESS_KEY_ID").ok();
     let r2_secret_access_key = std::env::var("PIXI_TEST_R2_SECRET_ACCESS_KEY").ok();
     if r2_access_key_id.is_none()
@@ -1104,6 +1357,8 @@ async fn install_s3() {
 
 #[tokio::test]
 async fn test_exclude_newer() {
+    setup_tracing();
+
     let mut package_database = PackageDatabase::default();
 
     // Create a channel with two packages with different timestamps
@@ -1175,6 +1430,8 @@ async fn test_exclude_newer() {
 #[tokio::test]
 #[cfg_attr(not(feature = "slow_integration_tests"), ignore)]
 async fn test_exclude_newer_pypi() {
+    setup_tracing();
+
     let pixi = PixiControl::from_manifest(&format!(
         r#"
     [workspace]
